4 ms·
I am surprised that it didn't get any attention here. I have skimmed the paper, and it seems that they got 1.6x faster with Rust rewrite that is more or less th
by aiono 2y ago
I am surprised that it didn't get any attention here. I have skimmed the paper, and it seems that they got 1.6x faster with Rust rewrite that is more or less the same code. Both versions are sequential code. And then changed Rust to be parallel and got 5.6x faster. They emphasize that converting to parallel was pretty straightforward because all they did was to change a method to be called. Since rest of it is iterator based code it pretty much worked as is. Only parts required change was sharing state between threads which would lead to bugs unless changed.
Probably there is still a lot of room for improvement if they can avoid mutex and use some lock-free mechanism as well. But I think it's nice to see Rust's promise of speed and safety in a real case.